package sun.security.validator;

import java.security.AlgorithmConstraints;
import java.util.List;
import java.util.Collections;
import java.security.cert.CertificateException;
import java.security.cert.PKIXBuilderParameters;
import java.util.Collection;
import java.security.KeyStore;
import java.util.Date;
import java.security.cert.X509Certificate;

public abstract class Validator
{
    static final X509Certificate[] CHAIN0;
    public static final String TYPE_SIMPLE = "Simple";
    public static final String TYPE_PKIX = "PKIX";
    public static final String VAR_GENERIC = "generic";
    public static final String VAR_CODE_SIGNING = "code signing";
    public static final String VAR_JCE_SIGNING = "jce signing";
    public static final String VAR_TLS_CLIENT = "tls client";
    public static final String VAR_TLS_SERVER = "tls server";
    public static final String VAR_TSA_SERVER = "tsa server";
    public static final String VAR_PLUGIN_CODE_SIGNING = "plugin code signing";
    private final String type;
    final EndEntityChecker endEntityChecker;
    final String variant;
    @Deprecated
    volatile Date validationDate;
    
    Validator(String type, String variant) {
        this.type = type;
        this.variant = variant;
        this.endEntityChecker = EndEntityChecker.getInstance(type, variant);
    }
    
    public static Validator getInstance(String s, String s2, KeyStore keyStore) {
        return getInstance(s, s2, TrustStoreUtil.getTrustedCerts(keyStore));
    }
    
    public static Validator getInstance(String str, String s, Collection<X509Certificate> collection) {
        if (str.equals("Simple")) {
            return new SimpleValidator(s, collection);
        }
        if (str.equals("PKIX")) {
            return new PKIXValidator(s, collection);
        }
        throw new IllegalArgumentException("Unknown validator type: " + str);
    }
    
    public static Validator getInstance(String s, String s2, PKIXBuilderParameters pkixBuilderParameters) {
        if (!s.equals("PKIX")) {
            throw new IllegalArgumentException("getInstance(PKIXBuilderParameters) can only be used with PKIX validator");
        }
        return new PKIXValidator(s2, pkixBuilderParameters);
    }
    
    public final X509Certificate[] validate(X509Certificate[] array) throws CertificateException {
        return this.validate(array, null, null);
    }
    
    public final X509Certificate[] validate(X509Certificate[] array, Collection<X509Certificate> collection) throws CertificateException {
        return this.validate(array, collection, null);
    }
    
    public final X509Certificate[] validate(X509Certificate[] array, Collection<X509Certificate> collection, Object o) throws CertificateException {
        return this.validate(array, collection, Collections.emptyList(), null, o);
    }
    
    public final X509Certificate[] validate(X509Certificate[] engineValidate, Collection<X509Certificate> collection, List<byte[]> list, AlgorithmConstraints algorithmConstraints, Object o) throws CertificateException {
        engineValidate = this.engineValidate(engineValidate, collection, list, algorithmConstraints, o);
        if (engineValidate.length > 1) {
            this.endEntityChecker.check(engineValidate, o, this.type != "PKIX");
            return engineValidate;
        }
        return engineValidate;
    }
    
    abstract X509Certificate[] engineValidate(X509Certificate[] p0, Collection<X509Certificate> p1, List<byte[]> p2, AlgorithmConstraints p3, Object p4) throws CertificateException;
    
    public abstract Collection<X509Certificate> getTrustedCertificates();
    
    @Deprecated
    public void setValidationDate(Date validationDate) {
        this.validationDate = validationDate;
    }
    
    static {
        CHAIN0 = new X509Certificate[0];
    }
}
